Cache

Struct Cache 

pub struct Cache { /* private fields */ }
Represents the sandboxed package cache.

Implementations

Source

impl Cache

pub fn new_with_proxies( pkg_cache_proxy: PackageCacheProxy, ) -> Result<Self, Error>

Construct a new Cache object with pre-created proxies to package cache, and space manager.

pub fn new() -> Result<Self, Error>

Construct a new Cache object using capabilities available in the namespace of the component calling this function. Should be the default in production usage, as these capabilities should be statically routed (i.e. from pkg-recovery.cml).